/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gtk;
/**
 * The Progress widget is the base class of {@link ProgressBar}. The Progress
 * class exists in Gtk for compatibility with programs written prior to Gtk2.
 * All methods have been deprecated and so are not present in Java-Gnome
 * @see ProgressBar
 */
public class Progress extends Widget 
{	
	Progress(int handle) {
	    super(handle);
	}

	//
	// This class is all deprecated as of Gnome 2
	//
	
    /****************************************
     * BEGINNING OF GENERATED CODE
     ****************************************/
    native static final protected double getXAlign (int cptr);
    native static final protected double getYAlign (int cptr);
    native static final protected boolean getShowText (int cptr);
    native static final protected boolean getActivityMode (int cptr);
    native static final protected boolean getUseTextFormat (int cptr);
    native static final protected String getFormat (int cptr);
    native static final protected int getAdjustment (int cptr);
    native static final protected int getOffscreenPixmap (int cptr);
    /****************************************
     * END OF GENERATED CODE
     ****************************************/
}

